==> jc-1.4.0.tar.gz: soot/relations/Domain.h <==
// public class soot.relations.Domain

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6e097004b1eff89b soot_relations_Domain

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_Domain_H_
#define _JC_soot_relations_Domain_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_relations_Domain$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_relations_Domain$sub_refs	_jc_soot_relations_Domain$sub_refs;
typedef struct _jc_soot_relations_Domain$sub_nonrefs	_jc_soot_relations_Domain$sub_nonrefs;
typedef struct _jc_soot_relations_Domain$refs	_jc_soot_relations_Domain$refs;
typedef struct _jc_soot_relations_Domain$nonrefs	_jc_soot_relations_Domain$nonrefs;
typedef struct _jc_soot_relations_Domain$object	_jc_soot_relations_Domain$object;

typedef const struct _jc_soot_relations_Domain$vmethods	_jc_soot_relations_Domain$vmethods;
typedef const struct _jc_soot_relations_Domain$vtable	_jc_soot_relations_Domain$vtable;
typedef const struct _jc_soot_relations_Domain$vtype	_jc_soot_relations_Domain$vtype;

// Constructors
extern void _jc_soot_relations_Domain$method$_init$8c7097b88cd3615e(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_util_Numberer$object *);
extern void _jc_soot_relations_Domain$method$_init$a777fb7461293998(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_util_Numberer$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_soot_util_Numberer$object *_jc_soot_relations_Domain$method$numberer$34f15cb451bff14a(_jc_env *, struct _jc_soot_relations_Domain$object *);
extern struct _jc_java_lang_String$object *_jc_soot_relations_Domain$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_relations_Domain$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_relations_Domain$method_info$numberer$34f15cb451bff14a;
extern _jc_method _jc_soot_relations_Domain$method_info$toString$7ea43b33b80a3070;

// Static methods
extern _jc_object_array *_jc_soot_relations_Domain$method$box$25fd31e2e5211410(_jc_env *, struct _jc_soot_relations_Domain$object *);
extern _jc_object_array *_jc_soot_relations_Domain$method$box$f3f774ffefe12e98(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_relations_Domain$object *);
extern _jc_object_array *_jc_soot_relations_Domain$method$box$abceae6f941da37b(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_relations_Domain$object *);
extern struct _jc_java_lang_String$object *_jc_soot_relations_Domain$method$toString$6c97b339b4209b12(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_soot_relations_Domain$vmethods {
	struct _jc_soot_util_Numberer$object	*(*numberer$34f15cb451bff14a)(_jc_env *, struct _jc_soot_relations_Domain$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_relations_Domain$object *);
};

// Vtable
struct _jc_soot_relations_Domain$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_Domain$vmethods	soot_relations_Domain;
};

// Vtype
struct _jc_soot_relations_Domain$vtype {
	_jc_type			type;
	_jc_soot_relations_Domain$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_Domain$sub_refs {
	struct _jc_soot_util_Numberer$object	*numberer;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_relations_Domain$refs {
    _jc_soot_relations_Domain$sub_refs	soot_relations_Domain;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_Domain$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_relations_Domain$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_Domain$sub_nonrefs	soot_relations_Domain;
};

// Object instance structure
struct _jc_soot_relations_Domain$object {
	_jc_soot_relations_Domain$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_Domain$vtype	*vtype;
	_jc_soot_relations_Domain$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_Domain$vtype _jc_soot_relations_Domain$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_Domain, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_Domain$class_object;

#endif	/* _JC_soot_relations_Domain_H_ */

==> jc-1.4.6.tar.gz: soot/relations/Domain.h <==
// public class soot.relations.Domain

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6e097004b1eff89b soot_relations_Domain

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_Domain_H_
#define _JC_soot_relations_Domain_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_relations_Domain$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_relations_Domain$sub_refs	_jc_soot_relations_Domain$sub_refs;
typedef struct _jc_soot_relations_Domain$sub_nonrefs	_jc_soot_relations_Domain$sub_nonrefs;
typedef struct _jc_soot_relations_Domain$refs	_jc_soot_relations_Domain$refs;
typedef struct _jc_soot_relations_Domain$nonrefs	_jc_soot_relations_Domain$nonrefs;
typedef struct _jc_soot_relations_Domain$object	_jc_soot_relations_Domain$object;

typedef const struct _jc_soot_relations_Domain$vmethods	_jc_soot_relations_Domain$vmethods;
typedef const struct _jc_soot_relations_Domain$vtable	_jc_soot_relations_Domain$vtable;
typedef const struct _jc_soot_relations_Domain$vtype	_jc_soot_relations_Domain$vtype;

// Constructors
extern void _jc_soot_relations_Domain$method$_init$8c7097b88cd3615e(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_relations_Domain$method$_init$a777fb7461293998(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_util_Numberer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_util_Numberer$object *_jc_soot_relations_Domain$method$numberer$34f15cb451bff14a(_jc_env *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_relations_Domain$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_relations_Domain$method_info$numberer$34f15cb451bff14a;
extern _jc_method _jc_soot_relations_Domain$method_info$toString$7ea43b33b80a3070;

// Static methods
extern _jc_object_array *_jc_soot_relations_Domain$method$box$25fd31e2e5211410(_jc_env *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_soot_relations_Domain$method$box$f3f774ffefe12e98(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_soot_relations_Domain$method$box$abceae6f941da37b(_jc_env *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_relations_Domain$object *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_relations_Domain$method$toString$6c97b339b4209b12(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_relations_Domain$vmethods {
	struct _jc_soot_util_Numberer$object	*(*numberer$34f15cb451bff14a)(_jc_env *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_relations_Domain$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_relations_Domain$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_Domain$vmethods	soot_relations_Domain;
};

// Vtype
struct _jc_soot_relations_Domain$vtype {
	_jc_type			type;
	_jc_soot_relations_Domain$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_Domain$sub_refs {
	struct _jc_soot_util_Numberer$object	*numberer;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_relations_Domain$refs {
    _jc_soot_relations_Domain$sub_refs	soot_relations_Domain;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_Domain$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_relations_Domain$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_Domain$sub_nonrefs	soot_relations_Domain;
};

// Object instance structure
struct _jc_soot_relations_Domain$object {
	_jc_soot_relations_Domain$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_Domain$vtype	*vtype;
	_jc_soot_relations_Domain$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_Domain$vtype _jc_soot_relations_Domain$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_Domain, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_Domain$class_object;

#endif	/* _JC_soot_relations_Domain_H_ */
